@@ -37,13 +37,8 @@ def _normalize_url(url: str) -> str:
     # os.path.normpath mangles url schemes: gs://etc -> gs:/etc
     # urlparse.urljoin doesn't normalize paths
     url_scheme, sep, url_path = url.partition("://")
-    # 2021-03-12 @ludwig this method is often called with paths that are not URLs.
-    # thus, url_path may be empty 
-    # in this case we can't call `os.path.normpath(url_path)`
-    # as it "normalizes" an empty input to "." (current directory)
-    normalized_path = os.path.normpath(url_path) if url_path else ""
-    joined = url_scheme + sep + normalized_path
-    return joined
+    normalized_path = os.path.normpath(url_path)
+    return url_scheme + sep + normalized_path
 
 
 def scope_url(url, io_scopes=None):
@@ -52,5 +47,4 @@ def scope_url(url, io_scopes=None):
         return url
     paths = io_scopes + [url]
     joined = os.path.join(*paths)
-    normalized = _normalize_url(joined)
-    return normalized
+    return _normalize_url(joined)
